@@ -185,8 +185,8 @@ def get_mqtt_status():
 class Dxr_Subscriber:
     def __init__(self, topic, callback):
         global callback_dit, topic_list_str_pub, topic_list_str_sub, mqttc, sn
-        if sn is not None:
-            topic = '/' + sn + '/client' + topic
+        if sn is not None and sn not in topic:
+            topic = f'/{sn}/client{topic}'
         if mqttc is None:
             mqttc = Mqtt()
         if isinstance(topic, str):
@@ -229,8 +229,6 @@ class dxr_subscriber:
 class Dxr_Publisher:
     def __init__(self, topic):
         global publish_dit, topic_list_str_pub, topic_list_str_sub, callback_dit, mqttc, sn
-        if sn is not None:
-            topic = '/' + sn + '/pc' + topic
         if mqttc is None:
             mqttc = Mqtt()
         if isinstance(topic, str):
@@ -239,6 +237,8 @@ class Dxr_Publisher:
         else:
             self.topic = topic.topic
             self.data_type = topic
+        if sn is not None and sn not in self.topic:
+            self.topic = f'/{sn}/pc{self.topic}'
         if self.topic not in publish_dit:
             publish_dit.append(self.topic)
         topic_list_str_pub = client_id + '_pub:\n'
@@ -253,9 +253,11 @@ class Dxr_Publisher:
         if mqttc is None:
             mqttc = Mqtt()
         try:
+            # print(f'self.data_type:{self.data_type}')
             if self.data_type:
                 if mqttc is not None:
                     if mqttc.is_connected():
+                        # print(f'publish:{self.topic}, msg:{msg.get_json()}')
                         mqttc.publish(self.topic, msg.get_json(), qos=0)
             else:
                 if mqttc is not None:
@@ -296,6 +298,7 @@ class Dxr_Publisher:
                 await_topic = topic.topic
         if await_topic is None:
             return None
+        await_topic = await_topic.replace('pc', 'client')
         # print('await_publish: ' + await_topic)
         cond = get_cond(await_topic)
         if cond is None:
